==> sat4j_2.3.3.orig.tar.gz: sat4j-2.3.3/org.sat4j.pb/src/main/java/org/sat4j/pb/tools/LexicoHelper.java <==
/*******************************************************************************
 * SAT4J: a SATisfiability library for Java Copyright (C) 2004, 2012 Artois University and CNRS
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 *  http://www.eclipse.org/legal/epl-v10.html
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU Lesser General Public License Version 2.1 or later (the
 * "LGPL"), in which case the provisions of the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of the LGPL, and not to allow others to use your version of
 * this file under the terms of the EPL, indicate your decision by deleting
 * the provisions above and replace them with the notice and other provisions
 * required by the LGPL. If you do not delete the provisions above, a recipient
 * may use your version of this file under the terms of the EPL or the LGPL.
 *
 * Based on the original MiniSat specification from:
 *
 * An extensible SAT solver. Niklas Een and Niklas Sorensson. Proceedings of the
 * Sixth International Conference on Theory and Applications of Satisfiability
 * Testing, LNCS 2919, pp 502-518, 2003.
 *
 * See www.minisat.se for the original solver in C++.
 *
 * Contributors:
 *   CRIL - initial API and implementation
 *******************************************************************************/
package org.sat4j.pb.tools;

import java.math.BigInteger;
import java.util.Collection;

import org.sat4j.core.Vec;
import org.sat4j.core.VecInt;
import org.sat4j.pb.IPBSolver;
import org.sat4j.pb.OptToPBSATAdapter;
import org.sat4j.pb.PBSolverDecorator;
import org.sat4j.specs.IVec;
import org.sat4j.specs.IVecInt;

public class LexicoHelper<T, C> extends DependencyHelper<T, C> {

    private final LexicoDecoratorPB lexico;

    public LexicoHelper(IPBSolver solver) {
        super(new OptToPBSATAdapter(new LexicoDecoratorPB(solver)));
        this.lexico = (LexicoDecoratorPB) ((PBSolverDecorator) getSolver())
                .decorated();
    }

    public LexicoHelper(IPBSolver solver, boolean explanationEnabled,
            boolean canonicalOptFunctionEnabled) {
        super(new OptToPBSATAdapter(new LexicoDecoratorPB(solver)),
                explanationEnabled, canonicalOptFunctionEnabled);
        this.lexico = (LexicoDecoratorPB) ((PBSolverDecorator) getSolver())
                .decorated();
    }

    public LexicoHelper(IPBSolver solver, boolean explanationEnabled) {
        super(new OptToPBSATAdapter(new LexicoDecoratorPB(solver)),
                explanationEnabled);
        this.lexico = (LexicoDecoratorPB) ((PBSolverDecorator) getSolver())
                .decorated();
    }

    public void addCriterion(Collection<T> things) {
        IVecInt literals = new VecInt(things.size());
        for (T thing : things) {
            literals.push(getIntValue(thing));
        }
        this.lexico.addCriterion(literals);
    }

    public void addWeightedCriterion(Collection<WeightedObject<T>> things) {
        IVecInt literals = new VecInt(things.size());
        IVec<BigInteger> coefs = new Vec<BigInteger>(things.size());
        for (WeightedObject<T> wo : things) {
            literals.push(getIntValue(wo.thing));
            coefs.push(wo.getWeight());
        }
        this.lexico.addCriterion(literals, coefs);
    }

    public boolean isOptimal() {
        return ((OptToPBSATAdapter) getSolver()).isOptimal();
    }
}

==> sat4j_2.3.5.orig.tar.gz: sat4j-2.3.5/org.sat4j.pb/src/main/java/org/sat4j/pb/tools/LexicoHelper.java <==
/*******************************************************************************
 * SAT4J: a SATisfiability library for Java Copyright (C) 2004, 2012 Artois University and CNRS
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 *  http://www.eclipse.org/legal/epl-v10.html
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU Lesser General Public License Version 2.1 or later (the
 * "LGPL"), in which case the provisions of the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of the LGPL, and not to allow others to use your version of
 * this file under the terms of the EPL, indicate your decision by deleting
 * the provisions above and replace them with the notice and other provisions
 * required by the LGPL. If you do not delete the provisions above, a recipient
 * may use your version of this file under the terms of the EPL or the LGPL.
 *
 * Based on the original MiniSat specification from:
 *
 * An extensible SAT solver. Niklas Een and Niklas Sorensson. Proceedings of the
 * Sixth International Conference on Theory and Applications of Satisfiability
 * Testing, LNCS 2919, pp 502-518, 2003.
 *
 * See www.minisat.se for the original solver in C++.
 *
 * Contributors:
 *   CRIL - initial API and implementation
 *******************************************************************************/
package org.sat4j.pb.tools;

import org.sat4j.pb.IPBSolver;

public class LexicoHelper<T, C> extends AbstractLexicoHelper<T, C> {

    public LexicoHelper(IPBSolver solver) {
        super(new LexicoDecoratorPB(solver));
    }

    public LexicoHelper(IPBSolver solver, boolean explanationEnabled,
            boolean canonicalOptFunctionEnabled) {
        super(new LexicoDecoratorPB(solver), explanationEnabled,
                canonicalOptFunctionEnabled);
    }

    public LexicoHelper(IPBSolver solver, boolean explanationEnabled) {
        super(new LexicoDecoratorPB(solver), explanationEnabled);
    }

}
